# hips

Documentation: [https://docs.album.solutions/](https://docs.album.solutions)

The primary solution repository is available here: [https://solutions.capture-knowledge.org/](https://solutions.capture-knowledge.org/)

## Developers

- Kyle Harrington, Max Delbrueck Center for Molecular Medicine in the
Helmholtz Association
- Jan Philipp Albrecht, Max Delbrueck Center for Molecular Medicine in
  the Helmholtz Association
- Deborah Schmidt, Max Delbrueck Center for Molecular Medicine in
  the Helmholtz Association
